@@ -8,7 +8,7 @@ API_MANAGEMENT_LOCAL_PYTHON_COMPONENT_ID = 212
 API_MANAGEMENT_LOCAL_PYTHON_COMPONENT_NAME = "api-management-local-python-package"
 DEVELOPER_EMAIL = "heba.a@circ.zone"
 
-object1 = {
+api_management_local_python_code = {
     'component_id': API_MANAGEMENT_LOCAL_PYTHON_COMPONENT_ID,
     'component_name': API_MANAGEMENT_LOCAL_PYTHON_COMPONENT_NAME,
     'component_category': LoggerComponentEnum.ComponentCategory.Code.value,
@@ -16,22 +16,20 @@ object1 = {
 }
 load_dotenv()
 
-logger=Logger.create_logger(object=object1)
-class APILimit( GenericCRUD):
+logger=Logger.create_logger(object=api_management_local_python_code)
+class APILimitsLocal( GenericCRUD):
     def __init__(self) -> None:
-         super().__init__("api_limit")
-    
+         super().__init__(schema_name="api_limit",default_table_name="api_limit_view")
     
     def get_limits_by_api_type_id(self,api_type_id:str)->list:
         logger.start(object={'api_type_id':api_type_id})
         try:
            select_clause="soft_limit,hard_limit"
-           api_str="api_type_id="+api_type_id
-           list=self.select_multi_by_where(view_table_name="api_limit_view",select_clause_value=select_clause,where=api_str)
+           list=self.select_multi_tuple_by_where(select_clause_value=select_clause,where=str(api_type_id))
            logger.end(object={'list':str(list)})
            return list 
         except Exception as exception:
             logger.exception(object=exception)
             logger.end()
-            raise
+            
             
